Separates the data in the given array into a two-dimensional array containing only the maximum number of elements.
For example, if you have an array of 6 data in 2 groups, this function will create a 2-dimensional array with 3 lengths.
Returns true if the first argument is in the range of the second argument ([min, max]).
To allow the minimum and maximum values to be in the range, pass true for the third argument.
Capitalize the first letter of every sentence. Typically, the . characters to separate sentences, but this can be customized via the value of the splitChar argument.
Returns true if the first string argument contains the second argument "string" or "one or more of the strings listed in the array". If the exact value is true, it returns true only for an exact match.
When the given function is executed repeatedly, the function is called if it has not been called again within the specified timeout.
This function is used when a small number of function calls are needed for repetitive input events.
Converts the file size in bytes to human-readable and returns it.
The return value is a String and includes the file units (Bytes, MB, GB...).
If the second optional argument value is included, you can display as many decimal places as you like.
Returns the file in the specified path as a value hashed by a specific algorithm. The default algorithm is md5. This method uses a Promise to return a valid hash value.
It compares the first argument value as the left operand and the argument values given thereafter as the right operand, and returns true if the values are all the same.
It compares the first argument value as the left operand and the argument values given thereafter as the right operand, and returns true if the values are all the same.
isEqual returns true even if the data types do not match, but isEqualStrict returns true only when the data types of all argument values match.
Returns true if the given data is in the correct URL format.
If withProtocol is true, it is automatically appended to the URL when the protocol does not exist.
If strict is true, URLs without commas (.) return false.
Determines whether the passed path or filename is using a system-accepted string (Also check the valid file length). Returns false if the name is not available.
Merges objects from the given object to the top level of the child items and displays the key names in steps, using a delimiter (. by default) instead of the existing keys.
For example, if an object a has keys b, c, and d, the a key is not displayed, and the keys and values a.b, a.c, and a.d are displayed in the parent step.
Converts the given object to array format. The resulting array is a two-dimensional array with one key value stored as follows: [key, value].
If the recursive option is true, it will convert to a two-dimensional array again when the value is of type object.
Removes the first-level path from a URL or pathname. Use this when you need a locale-free path in special cases in a URL that normally uses locale prefixes. For example, /en/hello is converted to /hello.
Returns after removing all special characters, including spaces. If you want to allow any special characters as exceptions, list them in the second argument value without delimiters. For example, if you want to allow spaces and the symbols & and *, the second argument value would be ' &*'.
Replaces text within a range starting and ending with a specific character in a given string with another string. For example, given the string abc<DEF>ghi, to change <DEF> to def, use replaceBetween('abc<DEF>ghi', '<', '>', 'def'). The result would be abcdefghi.
Deletes strings in the range if replaceWith is not specified.
Attempts to parse without returning an error, even if the argument value is of the wrong type or in JSON format.
If parsing fails, it will be replaced with the object set in fallback.
The default value for fallback is an empty object.
Any argument value will be attempted to be parsed as a Number type without returning an error.
If parsing fails, it is replaced by the number set in fallback.
The default value for fallback is 0. You can specify radix (default is decimal: 10) in the third argument.
Splits a string based on the specified character and returns it as an Array. Unlike the existing split, it splits the values provided as multiple parameters (array or multiple arguments) at once.
Returns the last line of the specified text file path. The length argument is the total number of lines to print. Default is 1. The last line of newline characters is ignored.
Removes all whitespace before and after a string. Unlike JavaScript's trim function, it converts two or more spaces between sentences into a single space.
The string ignores truncation until the ending character (endStringChar). If the expected length is reached, return the truncated string until after the ending character.